hyperspy\.tests\.component package
==================================

Submodules
----------

hyperspy\.tests\.component\.test\_component\_active\_array module
-----------------------------------------------------------------

.. automodule:: hyperspy.tests.component.test_component_active_array
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.component\.test\_component\_set\_parameters module
-------------------------------------------------------------------

.. automodule:: hyperspy.tests.component.test_component_set_parameters
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.tests\.component\.test\_gaussianhf module
---------------------------------------------------

.. automodule:: hyperspy.tests.component.test_gaussianhf
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.tests.component
    :members:
    :undoc-members:
    :show-inheritance:
